@@ -1,13 +1,18 @@
 """
 Versioning It with your Version In Git
 
-``versioningit`` is yet another setuptools plugin for automatically determining
-your package's version based on your Git repository's tags.  Unlike others, it
-allows easy customization of the version format and even lets you easily
-override the separate functions used for version extraction & calculation.
+``versioningit`` is yet another Python packaging plugin for automatically
+determining your package's version based on your version control repository's
+tags.  Unlike others, it allows easy customization of the version format and
+even lets you easily override the separate functions used for version
+extraction & calculation.
 
 **Features:**
 
+- Works with both setuptools and Hatch_
+
+  .. _hatch: https://hatch.pypa.io
+
 - Installed & configured through :pep:`518`'s ``pyproject.toml``
 
 - Supports Git, modern Git archives, and Mercurial
@@ -38,7 +43,7 @@ Visit <https://github.com/jwodder/versioningit> or
 <https://versioningit.rtfd.io> for more information.
 """
 
-__version__ = "2.2.1"
+__version__ = "2.3.0"
 __author__ = "John Thorvald Wodder II"
 __author_email__ = "versioningit@varonathe.org"
 __license__ = "MIT"
